==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coremotion/CMErrorCode.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coremotion;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
@ForceLinkClass(CMError.class)
/*<annotations>*//*</annotations>*/
public enum /*<name>*/CMErrorCode/*</name>*/ implements NSErrorCode {
    /*<values>*/
    NULL(100L),
    DeviceRequiresMovement(101L),
    TrueNorthNotAvailable(102L),
    Unknown(103L),
    MotionActivityNotAvailable(104L),
    MotionActivityNotAuthorized(105L),
    MotionActivityNotEntitled(106L),
    InvalidParameter(107L),
    InvalidAction(108L),
    NotAvailable(109L),
    NotEntitled(110L),
    NotAuthorized(111L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/CMErrorCode/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/CMErrorCode/*</name>*/ valueOf(long n) {
        for (/*<name>*/CMErrorCode/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/CMErrorCode/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/coremotion/CMErrorCode.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coremotion;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
@ForceLinkClass(CMError.class)
/*<annotations>*//*</annotations>*/
public enum /*<name>*/CMErrorCode/*</name>*/ implements NSErrorCode {
    /*<values>*/
    NULL(100L),
    DeviceRequiresMovement(101L),
    TrueNorthNotAvailable(102L),
    Unknown(103L),
    MotionActivityNotAvailable(104L),
    MotionActivityNotAuthorized(105L),
    MotionActivityNotEntitled(106L),
    InvalidParameter(107L),
    InvalidAction(108L),
    NotAvailable(109L),
    NotEntitled(110L),
    NotAuthorized(111L),
    NilData(112L),
    Size(113L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/CMErrorCode/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/CMErrorCode/*</name>*/ valueOf(long n) {
        for (/*<name>*/CMErrorCode/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/CMErrorCode/*</name>*/.class.getName());
    }
}
